#ifndef _OPTIONS_H
#define _OPTIONS_H

#define RCFILE		".abook.conf"
#define SYSWIDE_RCFILE	"/etc/abook.conf"

#include "conff.h"

int	options_get_int(char *section, char *key);
char	*options_get_str(char *section, char *key);
void	init_options();
void	edit_options();
void	close_config();
void	load_options();
void	save_options();

#endif
